@@ -1,13 +1,21 @@
+/* MAX_THREADS removed by Steve Underwood 1999/12/10 */
+
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
+#include "../libltdl/ltdl.h"
+
 #ifdef STDC_HEADERS
 # include <string.h>
 # include <stdlib.h>
 # include <stdio.h>
 #endif
 
+#ifdef HAVE_DIRENT_H
+# include <dirent.h>
+#endif
+
 #ifdef HAVE_STRINGS_H
 # include <strings.h>
 #endif
@@ -16,6 +24,10 @@
 # include <unistd.h>
 #endif
 
+#ifdef HAVE_LIBPTHREAD
+# include <pthread.h>
+#endif
+
 #if SIZEOF_UNSIGNED_LONG_INT == 4
  typedef unsigned long word32;
  typedef signed long sword32;
@@ -40,9 +52,6 @@
 # error "Cannot find an 8 bit char in your system, sorry."
 #endif
 
-/* originally was in 3way.c */
-#define RAND32 (word32) ((word32)rand() << 17 ^ (word32)rand() << 9 ^ rand())
-
 #ifndef HAVE_MEMMOVE
 # ifdef HAVE_BCOPY
 #  define memmove(d, s, n) bcopy ((s), (d), (n))
@@ -51,7 +60,5 @@
 # endif
 #endif
 
-#define ENCRYPT 0
-#define DECRYPT 1
 
 #define MAX_KEY_LEN 513 /* for gen_key */
