@@ -16,14 +16,18 @@
  * Boston, MA 02111-1307, USA.
  */
 
+/* $Id: xmemory.c,v 1.2 2000/02/28 13:20:21 nikos Exp $ */
+
 #ifndef LIBDEFS_H
 # define LIBDEFS_H
 # include <libdefs.h>
 #endif
 #include <bzero.h>
 
-#ifdef HAVE_SYS_MMAN_H
-# include <sys/mman.h>
+#ifdef HAVE_MLOCK
+# ifdef HAVE_SYS_MMAN_H
+#  include <sys/mman.h>
+# endif
 #endif
 
 #ifdef HAVE_MLOCK
@@ -60,11 +64,9 @@ void *mxmalloc(size_t size)
 			return x;
 		} else {
 			fprintf(stderr, ("Cannot allocate memory\n"));
-			exit(-1);
+			return NULL;
 		}
 	}
-/* Not really needed */
-	return x;
 }
 
 void *mxcalloc(size_t nmemb, size_t size)
@@ -73,8 +75,8 @@ void *mxcalloc(size_t nmemb, size_t size)
 
 	x = calloc(nmemb, size);
 	if (x != NULL) {
-		return x;
 		LOCKMEM(x, size);
+		return x;
 	} else {
 		sleep(1);
 		x = calloc(nmemb, size);
@@ -83,12 +85,9 @@ void *mxcalloc(size_t nmemb, size_t size)
 			return x;
 		} else {
 			fprintf(stderr, ("Cannot allocate memory\n"));
-			exit(-1);
+			return NULL;
 		}
 	}
-/* Not really needed */
-	return x;
-
 }
 
 void *mxrealloc(void *ptr, size_t size)
@@ -107,13 +106,9 @@ void *mxrealloc(void *ptr, size_t size)
 			return x;
 		} else {
 			fprintf(stderr, ("Cannot allocate memory\n"));
-			exit(-1);
+			return NULL;
 		}
 	}
-/* Not really needed */
-/* Just for some compilers which complain */
-	return x;
-
 }
 
 
